## Topsis_HarshitaSingh

# TOPSIS

**Submitted By**: Harshita Singh - 102003499.

Description: **Evaluation of alternatives based on multiple criteria using TOPSIS method.**.

---

## How to install this package:

```
>> pip install Topsis_HarshitaSingh_102003499
```

### In Command Prompt

```
>> python <program.py> <InputDataFile> <Weights> <Impacts> <ResultFileName>
```
